==> lessR_4.0.8.tar.gz: lessR/inst/doc/Proportions.R <==
## ----include=FALSE----------------------------------------------------------------------------------------------------
suppressPackageStartupMessages(library("lessR"))

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(n_succ=682, n_fail=243, p0=.75)

## ----read-------------------------------------------------------------------------------------------------------------
d <- Read("Jackets")

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(variable=Bike, success="BMW", p0=0.5)

## ---------------------------------------------------------------------------------------------------------------------
smokers <- c(83, 90, 129, 70)
names(smokers) <- c("Group1","Group2","Group3","Group4")
patients <- c(86, 93, 136, 82)
Prop_test(n_succ=smokers, n_tot=patients)

## ---------------------------------------------------------------------------------------------------------------------
sm1 <- c(rep("smoke", 83), rep("nosmoke", 3))
sm2 <- c(rep("smoke", 90), rep("nosmoke", 3))
sm3 <- c(rep("smoke", 129), rep("nosmoke", 7))
sm4 <- c(rep("smoke", 70), rep("nosmoke", 12))
sm <- c(sm1, sm2, sm3, sm4)
grp <- c(rep("A",86), rep("B",93), rep("C",136), rep("D",82))
d <- data.frame(sm, grp)

## ---------------------------------------------------------------------------------------------------------------------
head(d)

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(variable=sm, success="smoke", by=grp)

## ---------------------------------------------------------------------------------------------------------------------
x = c(372, 342, 311)
names(x) = c("Lite", "Med", "Thick")
Prop_test(n_tot=x)

## ---------------------------------------------------------------------------------------------------------------------
d <- Read("Jackets", quiet=TRUE)
Prop_test(Jacket)

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(n_table="FreqTable99")

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(Jacket, by=Bike)

## ---- fig.width=5-----------------------------------------------------------------------------------------------------
BarChart(Jacket, by=Bike)

## ---- fig.width=5-----------------------------------------------------------------------------------------------------
BarChart(Jacket, by=Bike, stack100=TRUE)

==> lessR_4.2.4.tar.gz: lessR/inst/doc/Proportions.R <==
## ----include=FALSE----------------------------------------------------------------------------------------------------
suppressPackageStartupMessages(library("lessR"))

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(n_succ=682, n_fail=243, pi=.75)

## ----read-------------------------------------------------------------------------------------------------------------
d <- Read("Jackets")

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(variable=Bike, success="BMW", pi=0.5)

## ---------------------------------------------------------------------------------------------------------------------
smokers <- c(83, 90, 129, 70)
names(smokers) <- c("Group1","Group2","Group3","Group4")
patients <- c(86, 93, 136, 82)
Prop_test(n_succ=smokers, n_tot=patients)

## ---------------------------------------------------------------------------------------------------------------------
sm1 <- c(rep("smoke", 83), rep("nosmoke", 3))
sm2 <- c(rep("smoke", 90), rep("nosmoke", 3))
sm3 <- c(rep("smoke", 129), rep("nosmoke", 7))
sm4 <- c(rep("smoke", 70), rep("nosmoke", 12))
sm <- c(sm1, sm2, sm3, sm4)
grp <- c(rep("A",86), rep("B",93), rep("C",136), rep("D",82))
d <- data.frame(sm, grp)

## ---------------------------------------------------------------------------------------------------------------------
head(d)

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(variable=sm, success="smoke", by=grp)

## ---------------------------------------------------------------------------------------------------------------------
x = c(372, 342, 311)
names(x) = c("Lite", "Med", "Thick")
Prop_test(n_tot=x)

## ---------------------------------------------------------------------------------------------------------------------
d <- Read("Jackets", quiet=TRUE)
Prop_test(Jacket)

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(n_table="FreqTable99")

## ---------------------------------------------------------------------------------------------------------------------
Prop_test(Jacket, by=Bike)

## ---- fig.width=5-----------------------------------------------------------------------------------------------------
BarChart(Jacket, by=Bike)

## ---- fig.width=5-----------------------------------------------------------------------------------------------------
BarChart(Jacket, by=Bike, stack100=TRUE)
